@@ -1,7 +1,7 @@
 # frozen_string_literal: true
 
 # Redmine - project management software
-# Copyright (C) 2006-2023  Jean-Philippe Lang
+# Copyright (C) 2006-  Jean-Philippe Lang
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -255,15 +255,18 @@ module Redmine
             [text, url]
           end
           links = texts_and_urls.sort_by(&:first).map do |text, url|
-            css_class = (/^https?:\/\//.match?(url)) ? 'external' : nil
-            view.link_to_if uri_with_safe_scheme?(url), text, url, :class => css_class
+            view.link_to text, url
           end
-          links.join(', ').html_safe
+          sanitize_html links.join(', ')
         else
           casted
         end
       end
 
+      def sanitize_html(html)
+        Redmine::WikiFormatting::HtmlSanitizer.call(html).html_safe
+      end
+
       # Returns an URL generated with the custom field URL pattern
       # and variables substitution:
       # %value% => the custom field value
@@ -273,15 +276,15 @@ module Redmine
       # %m1%, %m2%... => capture groups matches of the custom field regexp if defined
       def url_from_pattern(custom_field, value, customized)
         url = custom_field.url_pattern.to_s.dup
-        url.gsub!('%value%') {Addressable::URI.encode value.to_s}
-        url.gsub!('%id%') {Addressable::URI.encode customized.id.to_s}
+        url.gsub!('%value%') {Addressable::URI.encode_component value.to_s}
+        url.gsub!('%id%') {Addressable::URI.encode_component customized.id.to_s}
         url.gsub!('%project_id%') do
-          Addressable::URI.encode(
+          Addressable::URI.encode_component(
             (customized.respond_to?(:project) ? customized.project.try(:id) : nil).to_s
           )
         end
         url.gsub!('%project_identifier%') do
-          Addressable::URI.encode(
+          Addressable::URI.encode_component(
             (customized.respond_to?(:project) ? customized.project.try(:identifier) : nil).to_s
           )
         end
@@ -289,7 +292,7 @@ module Redmine
           url.gsub!(%r{%m(\d+)%}) do
             m = $1.to_i
             if matches ||= value.to_s.match(Regexp.new(custom_field.regexp))
-              Addressable::URI.encode matches[m].to_s
+              Addressable::URI.encode_component matches[m].to_s
             end
           end
         end
@@ -463,8 +466,7 @@ module Redmine
               url = "http://" + url
             end
           end
-          css_class = (/^https?:\/\//.match?(url)) ? 'external' : nil
-          view.link_to value.to_s.truncate(40), url, :class => css_class
+          sanitize_html view.link_to(value.to_s.truncate(40), url)
         else
           value.to_s
         end
@@ -866,7 +868,7 @@ module Redmine
 
       def possible_values_records(custom_field, object=nil)
         if object.is_a?(Array)
-          projects = object.map {|o| o.respond_to?(:project) ? o.project : nil}.compact.uniq
+          projects = object.filter_map {|o| o.respond_to?(:project) ? o.project : nil}.uniq
           projects.map {|project| possible_values_records(custom_field, project)}.reduce(:&) || []
         elsif object.respond_to?(:project) && object.project
           scope = object.project.users
@@ -932,7 +934,7 @@ module Redmine
 
       def possible_values_records(custom_field, object=nil, all_statuses=false)
         if object.is_a?(Array)
-          projects = object.map {|o| o.respond_to?(:project) ? o.project : nil}.compact.uniq
+          projects = object.filter_map {|o| o.respond_to?(:project) ? o.project : nil}.uniq
           projects.map {|project| possible_values_records(custom_field, project)}.reduce(:&) || []
         elsif object.respond_to?(:project) && object.project
           scope = object.project.shared_versions
@@ -971,7 +973,7 @@ module Redmine
           attachment_present = true
           value = value.except(:blank)
 
-          if value.values.any? && value.values.all? {|v| v.is_a?(Hash)}
+          if value.values.any? && value.values.all?(Hash)
             value = value.values.first
           end
 
